@@ -10,7 +10,7 @@ use Rose::DB::Object::Metadata::ForeignKey;
 use Rose::DB::Object::Metadata::Object;
 our @ISA = qw(Rose::DB::Object::Metadata::Object);
 
-our $VERSION = '0.752';
+our $VERSION = '0.753';
 
 our $Debug = 0;
 
@@ -182,6 +182,8 @@ sub plural_to_singular
     return $code->($word);
   }
 
+  return $word  if($word =~ /[aeiouy]ss$/i);
+
   $word =~ s/s$//;
   return $word;
 }
@@ -1118,7 +1120,9 @@ Get or set the L<Rose::DB::Object::Metadata> object associated with the class th
 
 =item B<plural_to_singular STRING>
 
-Returns the singular version of STRING.  If a L<plural_to_singular_function|/plural_to_singular_function> is defined, then this method simply passes STRING to that function.  Otherwise, "s" is removed from the end of STRING and the result is returned.
+Returns the singular version of STRING.  If a L<plural_to_singular_function|/plural_to_singular_function> is defined, then this method simply passes STRING to that function.
+
+Otherwise, the following rules are applied.  If STRING matches C</[aeiouy]ss$/i>, it is returned unmodified.  For all other cases, the letter "s" is removed from the end of STRING and the result is returned.
 
 =item B<plural_to_singular_function [CODEREF]>
 
